@@ -39,6 +39,7 @@ CURL_GLOBAL_DEFAULT
 CURL_GLOBAL_NOTHING
 CURL_GLOBAL_SSL
 CURL_GLOBAL_WIN32
+CURL_HET_DEFAULT
 CURL_HTTPPOST_BUFFER
 CURL_HTTPPOST_CALLBACK
 CURL_HTTPPOST_FILENAME
@@ -64,6 +65,7 @@ CURL_LOCK_DATA_CONNECT
 CURL_LOCK_DATA_COOKIE
 CURL_LOCK_DATA_DNS
 CURL_LOCK_DATA_NONE
+CURL_LOCK_DATA_PSL
 CURL_LOCK_DATA_SHARE
 CURL_LOCK_DATA_SSL_SESSION
 CURL_MAX_HTTP_HEADER
@@ -119,6 +121,7 @@ CURL_TIMECOND_NONE
 CURL_TLSAUTH_NONE
 CURL_TLSAUTH_SRP
 CURL_VERSION_ASYNCHDNS
+CURL_VERSION_BROTLI
 CURL_VERSION_CONV
 CURL_VERSION_CURLDEBUG
 CURL_VERSION_DEBUG
@@ -132,6 +135,7 @@ CURL_VERSION_KERBEROS4
 CURL_VERSION_KERBEROS5
 CURL_VERSION_LARGEFILE
 CURL_VERSION_LIBZ
+CURL_VERSION_MULTI_SSL
 CURL_VERSION_NTLM
 CURL_VERSION_NTLM_WB
 CURL_VERSION_PSL
@@ -141,6 +145,8 @@ CURL_VERSION_SSPI
 CURL_VERSION_TLSAUTH_SRP
 CURL_VERSION_UNIX_SOCKETS
 CURL_WRITEFUNC_PAUSE
+CURL_ZERO_TERMINATED
+CURLVERSION_FIFTH
 CURLVERSION_FIRST
 CURLVERSION_FOURTH
 CURLVERSION_NOW
@@ -150,6 +156,10 @@ CURLUSESSL_ALL
 CURLUSESSL_CONTROL
 CURLUSESSL_NONE
 CURLUSESSL_TRY
+CURLSSLSET_NO_BACKENDS
+CURLSSLSET_OK
+CURLSSLSET_TOO_LATE
+CURLSSLSET_UNKNOWN_BACKEND
 CURLSSLOPT_ALLOW_BEAST
 CURLSSLOPT_NO_REVOKE
 CURLSSLBACKEND_AXTLS
@@ -169,6 +179,7 @@ CURLSSLBACKEND_WOLFSSL
 CURLSSH_AUTH_AGENT
 CURLSSH_AUTH_ANY
 CURLSSH_AUTH_DEFAULT
+CURLSSH_AUTH_GSSAPI
 CURLSSH_AUTH_HOST
 CURLSSH_AUTH_KEYBOARD
 CURLSSH_AUTH_NONE
@@ -266,11 +277,13 @@ CURLOPT_DEBUGDATA
 CURLOPT_DEBUGFUNCTION
 CURLOPT_DEFAULT_PROTOCOL
 CURLOPT_DIRLISTONLY
+CURLOPT_DISALLOW_USERNAME_IN_URL
 CURLOPT_DNS_CACHE_TIMEOUT
 CURLOPT_DNS_INTERFACE
 CURLOPT_DNS_LOCAL_IP4
 CURLOPT_DNS_LOCAL_IP6
 CURLOPT_DNS_SERVERS
+CURLOPT_DNS_SHUFFLE_ADDRESSES
 CURLOPT_DNS_USE_GLOBAL_CACHE
 CURLOPT_EGDSOCKET
 CURLOPT_ENCODING
@@ -300,6 +313,8 @@ CURLOPT_FTP_USE_EPRT
 CURLOPT_FTP_USE_EPSV
 CURLOPT_FTP_USE_PRET
 CURLOPT_GSSAPI_DELEGATION
+CURLOPT_HAPPY_EYEBALLS_TIMEOUT_MS
+CURLOPT_HAPROXYPROTOCOL
 CURLOPT_HEADER
 CURLOPT_HEADERDATA
 CURLOPT_HEADERFUNCTION
@@ -342,6 +357,7 @@ CURLOPT_MAXFILESIZE_LARGE
 CURLOPT_MAXREDIRS
 CURLOPT_MAX_RECV_SPEED_LARGE
 CURLOPT_MAX_SEND_SPEED_LARGE
+CURLOPT_MIMEPOST
 CURLOPT_NETRC
 CURLOPT_NETRC_FILE
 CURLOPT_NEW_DIRECTORY_PERMS
@@ -393,6 +409,7 @@ CURLOPT_PROXY_SSL_CIPHER_LIST
 CURLOPT_PROXY_SSL_OPTIONS
 CURLOPT_PROXY_SSL_VERIFYHOST
 CURLOPT_PROXY_SSL_VERIFYPEER
+CURLOPT_PROXY_TLS13_CIPHERS
 CURLOPT_PROXY_TLSAUTH_PASSWORD
 CURLOPT_PROXY_TLSAUTH_TYPE
 CURLOPT_PROXY_TLSAUTH_USERNAME
@@ -407,6 +424,8 @@ CURLOPT_REDIR_PROTOCOLS
 CURLOPT_REFERER
 CURLOPT_REQUEST_TARGET
 CURLOPT_RESOLVE
+CURLOPT_RESOLVER_START_DATA
+CURLOPT_RESOLVER_START_FUNCTION
 CURLOPT_RESUME_FROM
 CURLOPT_RESUME_FROM_LARGE
 CURLOPT_RTSPHEADER
@@ -428,6 +447,7 @@ CURLOPT_SOCKS5_AUTH
 CURLOPT_SOCKS5_GSSAPI_NEC
 CURLOPT_SOCKS5_GSSAPI_SERVICE
 CURLOPT_SSH_AUTH_TYPES
+CURLOPT_SSH_COMPRESSION
 CURLOPT_SSH_HOST_PUBLIC_KEY_MD5
 CURLOPT_SSH_KEYDATA
 CURLOPT_SSH_KEYFUNCTION
@@ -471,6 +491,8 @@ CURLOPT_TIMECONDITION
 CURLOPT_TIMEOUT
 CURLOPT_TIMEOUT_MS
 CURLOPT_TIMEVALUE
+CURLOPT_TIMEVALUE_LARGE
+CURLOPT_TLS13_CIPHERS
 CURLOPT_TLSAUTH_PASSWORD
 CURLOPT_TLSAUTH_TYPE
 CURLOPT_TLSAUTH_USERNAME
@@ -506,6 +528,7 @@ CURLM_CALL_MULTI_PERFORM
 CURLM_INTERNAL_ERROR
 CURLM_OK
 CURLM_OUT_OF_MEMORY
+CURLM_RECURSIVE_API_CALL
 CURLM_UNKNOWN_OPTION
 CURLMSG_DONE
 CURLMSG_NONE
@@ -525,6 +548,8 @@ CURLMOPT_SOCKETFUNCTION
 CURLMOPT_TIMERDATA
 CURLMOPT_TIMERFUNCTION
 CURLKHTYPE_DSS
+CURLKHTYPE_ECDSA
+CURLKHTYPE_ED25519
 CURLKHTYPE_RSA
 CURLKHTYPE_RSA1
 CURLKHTYPE_UNKNOWN
@@ -542,9 +567,11 @@ CURLIOCMD_NOP
 CURLIOCMD_RESTARTREAD
 CURLINFO_ACTIVESOCKET
 CURLINFO_APPCONNECT_TIME
+CURLINFO_APPCONNECT_TIME_T
 CURLINFO_CERTINFO
 CURLINFO_CONDITION_UNMET
 CURLINFO_CONNECT_TIME
+CURLINFO_CONNECT_TIME_T
 CURLINFO_CONTENT_LENGTH_DOWNLOAD
 CURLINFO_CONTENT_LENGTH_DOWNLOAD_T
 CURLINFO_CONTENT_LENGTH_UPLOAD
@@ -557,6 +584,7 @@ CURLINFO_DOUBLE
 CURLINFO_EFFECTIVE_URL
 CURLINFO_END
 CURLINFO_FILETIME
+CURLINFO_FILETIME_T
 CURLINFO_FTP_ENTRY_PATH
 CURLINFO_HEADER_IN
 CURLINFO_HEADER_OUT
@@ -572,11 +600,13 @@ CURLINFO_LOCAL_PORT
 CURLINFO_LONG
 CURLINFO_MASK
 CURLINFO_NAMELOOKUP_TIME
+CURLINFO_NAMELOOKUP_TIME_T
 CURLINFO_NONE
 CURLINFO_NUM_CONNECTS
 CURLINFO_OFF_T
 CURLINFO_OS_ERRNO
 CURLINFO_PRETRANSFER_TIME
+CURLINFO_PRETRANSFER_TIME_T
 CURLINFO_PRIMARY_IP
 CURLINFO_PRIMARY_PORT
 CURLINFO_PRIVATE
@@ -586,6 +616,7 @@ CURLINFO_PROXY_SSL_VERIFYRESULT
 CURLINFO_PTR
 CURLINFO_REDIRECT_COUNT
 CURLINFO_REDIRECT_TIME
+CURLINFO_REDIRECT_TIME_T
 CURLINFO_REDIRECT_URL
 CURLINFO_REQUEST_SIZE
 CURLINFO_RESPONSE_CODE
@@ -609,11 +640,13 @@ CURLINFO_SSL_DATA_OUT
 CURLINFO_SSL_ENGINES
 CURLINFO_SSL_VERIFYRESULT
 CURLINFO_STARTTRANSFER_TIME
+CURLINFO_STARTTRANSFER_TIME_T
 CURLINFO_STRING
 CURLINFO_TEXT
 CURLINFO_TLS_SESSION
 CURLINFO_TLS_SSL_PTR
 CURLINFO_TOTAL_TIME
+CURLINFO_TOTAL_TIME_T
 CURLINFO_TYPEMASK
 CURLHEADER_SEPARATE
 CURLHEADER_UNIFIED
@@ -743,6 +776,7 @@ CURLE_PEER_FAILED_VERIFICATION
 CURLE_QUOTE_ERROR
 CURLE_RANGE_ERROR
 CURLE_READ_ERROR
+CURLE_RECURSIVE_API_CALL
 CURLE_RECV_ERROR
 CURLE_REMOTE_ACCESS_DENIED
 CURLE_REMOTE_DISK_FULL
@@ -795,6 +829,7 @@ CURLCLOSEPOLICY_SLOWEST
 CURLAUTH_ANY
 CURLAUTH_ANYSAFE
 CURLAUTH_BASIC
+CURLAUTH_BEARER
 CURLAUTH_DIGEST
 CURLAUTH_DIGEST_IE
 CURLAUTH_GSSAPI
